'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const VERSION = "1.0.1";

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);

    if (enumerableOnly) {
      symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });
    }

    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

// Credit: https://github.com/shinnn/github-username-regex/
const GITHUB_USERNAME_REGEX = /^[a-z\d](?:[a-z\d]|-(?=[a-z\d])){0,38}$/i;
async function composeGetOpenRepositoryIssuesCountByAssignees(octokit, {
  owner,
  repo,
  assignees
}) {
  const invalidUsernames = assignees.filter(login => !GITHUB_USERNAME_REGEX.test(login));

  if (invalidUsernames.length) {
    throw new Error(`[octokit-plugin-get-open-repository-issues-count-by-assignees] Invalid usernames: ${invalidUsernames.join(", ")}`);
  }

  const userIssuesNode = assignees.map((login, index) => `issues${index}:issues(first:1,states:OPEN,filterBy:{assignee:"${login}"}) { totalCount }`);
  const query = `
    query($owner:String!,$repo:String!) {
      repository(owner:$owner, name:$repo) {
        ${userIssuesNode.join("\n        ")}
      }
    }
  `;
  const {
    repository: result
  } = await octokit.graphql(query, {
    owner,
    repo
  });
  return Object.entries(result).reduce((countByAssignees, [key, {
    totalCount
  }]) => {
    const index = Number(key.substr("issues".length));
    return _objectSpread2(_objectSpread2({}, countByAssignees), {}, {
      [assignees[index]]: totalCount
    });
  }, {});
}

/**
 * @param octokit Octokit instance
 * @param options Options passed to Octokit constructor
 */

function getOpenRepositoryIssuesCountByAssignees(octokit) {
  return {
    getOpenRepositoryIssuesCountByAssignees: composeGetOpenRepositoryIssuesCountByAssignees.bind(null, octokit)
  };
}
getOpenRepositoryIssuesCountByAssignees.VERSION = VERSION;

exports.composeGetOpenRepositoryIssuesCountByAssignees = composeGetOpenRepositoryIssuesCountByAssignees;
exports.getOpenRepositoryIssuesCountByAssignees = getOpenRepositoryIssuesCountByAssignees;
//# sourceMappingURL=index.js.map
